#!/usr/bin/env python3

# Copyright (C) 2022, Jan-Philipp Litza (PLUTEX) <jpl@plutex.de>.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# https://nlnetlabs.nl/projects/unbound/about/

# changes by thl-cmk[at]outlook[dot]com
# 2024-04-21: removed Union -> no need "int | float" should do
#             added levels_upper_NOERROR to default parameters -> show up in info line
# 2024-05-22: changed time for get_rate from section to system time
#             added output in case get_rate is initialising (unknown state in discovery)
#             removed default levels for unbound_answers
#             added params for unwanted replies
# 2024-07-24: split unbound.py in separate files per check

from cmk.base.plugins.agent_based.agent_based_api.v1 import register
from cmk.base.plugins.agent_based.agent_based_api.v1.type_defs import StringTable
from cmk.base.plugins.agent_based.utils.unbound import UnboundSection


def parse_unbound(string_table: StringTable) -> UnboundSection:
    section = {}
    for key, value in string_table:
        try:
            section[key] = int(value)
        except ValueError:
            section[key] = float(value)

    return section


register.agent_section(
    name='unbound',
    parse_function=parse_unbound,
)
