#!/usr/bin/env python3

# Copyright (C) 2022, Jan-Philipp Litza (PLUTEX) <jpl@plutex.de>.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# https://nlnetlabs.nl/projects/unbound/about/

# changes by thl-cmk[at]outlook[dot]com
# 2024-04-21: removed Union -> no need "int | float" should do
#             added levels_upper_NOERROR to default parameters -> show up in info line
# 2024-05-22: changed time for get_rate from section to system time
#             added output in case get_rate is initialising (unknown state in discovery)
#             removed default levels for unbound_answers
#             added params for unwanted replies


from time import time as now_time

from cmk.base.plugins.agent_based.agent_based_api.v1.type_defs import (
    CheckResult,
    DiscoveryResult,
)

from cmk.base.plugins.agent_based.agent_based_api.v1 import (
    Service,
    check_levels,
    get_rate,
    get_value_store,
    register,
)

from cmk.base.plugins.agent_based.utils.unbound import (
    UnboundSection,
    render_qps,
)


def discover_unbound_unwanted_replies(section: UnboundSection) -> DiscoveryResult:
    if 'unwanted.replies' in section:
        yield Service()


def check_unbound_unwanted_replies(params, section: UnboundSection) -> CheckResult:
    if 'unwanted.replies' not in section:
        return

    rate = get_rate(
        get_value_store(),
        'unbound_unwanted_replies',
        now_time(),
        section['unwanted.replies'],
        raise_overflow=True,
    )

    yield from check_levels(
        value=rate,
        levels_upper=params.get('unwanted_replies'),
        metric_name='unbound_unwanted_replies',
        render_func=render_qps,
        label='Unwanted Replies',
    )


register.check_plugin(
    name='unbound_unwanted_replies',
    service_name='Unbound Unwanted Replies',
    sections=['unbound'],
    discovery_function=discover_unbound_unwanted_replies,
    check_function=check_unbound_unwanted_replies,
    check_default_parameters={},
    check_ruleset_name='unbound_replies',
)
